@@ -1,6 +1,8 @@
 #.First.lib <- function(lib, pkg) {
 #          library.dynam("maptools", pkg, lib)
 #}
-.noGenerics <- TRUE
+## .noGenerics <- TRUE
 #maptools()
 
+".onLoad" <- function(lib, pkg) require(methods)
+
